@@ -5,11 +5,6 @@ use test_case::test_case;
 
 use crypto_crawler::*;
 use crypto_markets::MarketType;
-use std::thread_local;
-use std::{
-    cell::RefCell,
-    sync::{Arc, Mutex},
-};
 
 const EXCHANGE_NAME: &str = "binance";
 
@@ -20,7 +15,7 @@ const EXCHANGE_NAME: &str = "binance";
 #[test_case(MarketType::LinearSwap, "BTCUSDT")]
 #[test_case(MarketType::EuropeanOption, "BTC-210129-40000-C"; "inconclusive")]
 fn test_crawl_trade(market_type: MarketType, symbol: &str) {
-    gen_test_code!(
+    test_one_symbol!(
         crawl_trade,
         EXCHANGE_NAME,
         market_type,
@@ -36,7 +31,7 @@ fn test_crawl_trade(market_type: MarketType, symbol: &str) {
 #[test_case(MarketType::LinearSwap, "BTCUSDT")]
 #[test_case(MarketType::EuropeanOption, "BTC-210129-40000-C"; "inconclusive")]
 fn test_crawl_l2_event(market_type: MarketType, symbol: &str) {
-    gen_test_code!(
+    test_one_symbol!(
         crawl_l2_event,
         EXCHANGE_NAME,
         market_type,
@@ -52,7 +47,7 @@ fn test_crawl_l2_event(market_type: MarketType, symbol: &str) {
 #[test_case(MarketType::LinearSwap, "BTCUSDT")]
 #[test_case(MarketType::EuropeanOption, "BTC-210129-40000-C"; "inconclusive")]
 fn test_crawl_bbo(market_type: MarketType, symbol: &str) {
-    gen_test_code!(
+    test_one_symbol!(
         crawl_bbo,
         EXCHANGE_NAME,
         market_type,
@@ -68,7 +63,7 @@ fn test_crawl_bbo(market_type: MarketType, symbol: &str) {
 #[test_case(MarketType::LinearSwap, "BTCUSDT")]
 #[test_case(MarketType::EuropeanOption, "BTC-210129-40000-C"; "inconclusive")]
 fn test_crawl_l2_topk(market_type: MarketType, symbol: &str) {
-    gen_test_code!(
+    test_one_symbol!(
         crawl_l2_topk,
         EXCHANGE_NAME,
         market_type,
@@ -84,7 +79,7 @@ fn test_crawl_l2_topk(market_type: MarketType, symbol: &str) {
 #[test_case(MarketType::LinearSwap, "BTCUSDT")]
 #[test_case(MarketType::EuropeanOption, "BTC-210129-40000-C"; "inconclusive")]
 fn test_crawl_l2_snapshot(market_type: MarketType, symbol: &str) {
-    gen_test_snapshot_code!(
+    test_one_symbol!(
         crawl_l2_snapshot,
         EXCHANGE_NAME,
         market_type,
@@ -99,7 +94,7 @@ fn test_crawl_l2_snapshot(market_type: MarketType, symbol: &str) {
 #[test_case(MarketType::InverseSwap)]
 #[test_case(MarketType::LinearSwap)]
 fn test_crawl_l2_snapshot_without_symbol(market_type: MarketType) {
-    gen_test_snapshot_without_symbol_code!(
+    test_all_symbols!(
         crawl_l2_snapshot,
         EXCHANGE_NAME,
         market_type,
@@ -114,7 +109,7 @@ fn test_crawl_l2_snapshot_without_symbol(market_type: MarketType) {
 #[test_case(MarketType::LinearSwap, "BTCUSDT")]
 #[test_case(MarketType::EuropeanOption, "BTC-210129-40000-C"; "inconclusive")]
 fn test_crawl_ticker(market_type: MarketType, symbol: &str) {
-    gen_test_code!(
+    test_one_symbol!(
         crawl_ticker,
         EXCHANGE_NAME,
         market_type,
@@ -126,7 +121,7 @@ fn test_crawl_ticker(market_type: MarketType, symbol: &str) {
 #[test_case(MarketType::InverseSwap, "BTCUSD_PERP")]
 #[test_case(MarketType::LinearSwap, "BTCUSDT")]
 fn test_crawl_funding_rate(market_type: MarketType, symbol: &str) {
-    gen_test_code!(
+    test_one_symbol!(
         crawl_funding_rate,
         EXCHANGE_NAME,
         market_type,
