@@ -5,18 +5,13 @@ use test_case::test_case;
 
 use crypto_crawler::*;
 use crypto_markets::MarketType;
-use std::thread_local;
-use std::{
-    cell::RefCell,
-    sync::{Arc, Mutex},
-};
 
 const EXCHANGE_NAME: &str = "bitfinex";
 
 #[test_case(MarketType::Spot, "tBTCUSD")]
 #[test_case(MarketType::LinearSwap, "tBTCF0:USTF0")]
 fn test_crawl_trade(market_type: MarketType, symbol: &str) {
-    gen_test_code!(
+    test_one_symbol!(
         crawl_trade,
         EXCHANGE_NAME,
         market_type,
@@ -28,7 +23,7 @@ fn test_crawl_trade(market_type: MarketType, symbol: &str) {
 #[test_case(MarketType::Spot, "tBTCUSD")]
 #[test_case(MarketType::LinearSwap, "tBTCF0:USTF0")]
 fn test_crawl_l2_event(market_type: MarketType, symbol: &str) {
-    gen_test_code!(
+    test_one_symbol!(
         crawl_l2_event,
         EXCHANGE_NAME,
         market_type,
@@ -40,7 +35,7 @@ fn test_crawl_l2_event(market_type: MarketType, symbol: &str) {
 #[test_case(MarketType::Spot, "tBTCUSD")]
 #[test_case(MarketType::LinearSwap, "tBTCF0:USTF0")]
 fn test_crawl_bbo(market_type: MarketType, symbol: &str) {
-    gen_test_code!(
+    test_one_symbol!(
         crawl_bbo,
         EXCHANGE_NAME,
         market_type,
@@ -52,7 +47,7 @@ fn test_crawl_bbo(market_type: MarketType, symbol: &str) {
 #[test_case(MarketType::Spot, "tBTCUSD")]
 #[test_case(MarketType::LinearSwap, "tBTCF0:USTF0")]
 fn test_crawl_l2_snapshot(market_type: MarketType, symbol: &str) {
-    gen_test_snapshot_code!(
+    test_one_symbol!(
         crawl_l2_snapshot,
         EXCHANGE_NAME,
         market_type,
@@ -64,7 +59,7 @@ fn test_crawl_l2_snapshot(market_type: MarketType, symbol: &str) {
 #[test_case(MarketType::Spot)]
 #[test_case(MarketType::LinearSwap)]
 fn test_crawl_l2_snapshot_without_symbol(market_type: MarketType) {
-    gen_test_snapshot_without_symbol_code!(
+    test_all_symbols!(
         crawl_l2_snapshot,
         EXCHANGE_NAME,
         market_type,
@@ -75,7 +70,7 @@ fn test_crawl_l2_snapshot_without_symbol(market_type: MarketType) {
 #[test_case(MarketType::Spot, "tBTCUSD")]
 #[test_case(MarketType::LinearSwap, "tBTCF0:USTF0")]
 fn test_crawl_l3_event(market_type: MarketType, symbol: &str) {
-    gen_test_code!(
+    test_one_symbol!(
         crawl_l3_event,
         EXCHANGE_NAME,
         market_type,
@@ -87,7 +82,7 @@ fn test_crawl_l3_event(market_type: MarketType, symbol: &str) {
 #[test_case(MarketType::Spot, "tBTCUSD")]
 #[test_case(MarketType::LinearSwap, "tBTCF0:USTF0")]
 fn test_crawl_l3_snapshot(market_type: MarketType, symbol: &str) {
-    gen_test_snapshot_code!(
+    test_one_symbol!(
         crawl_l3_snapshot,
         EXCHANGE_NAME,
         market_type,
@@ -99,7 +94,7 @@ fn test_crawl_l3_snapshot(market_type: MarketType, symbol: &str) {
 #[test_case(MarketType::Spot, "tBTCUSD")]
 #[test_case(MarketType::LinearSwap, "tBTCF0:USTF0")]
 fn test_crawl_ticker(market_type: MarketType, symbol: &str) {
-    gen_test_code!(
+    test_one_symbol!(
         crawl_ticker,
         EXCHANGE_NAME,
         market_type,
